***************************
The sherpa.models.op module
***************************

.. currentmodule:: sherpa.models.op

.. automodule:: sherpa.models.op

   .. rubric:: Symbols

   .. autosummary::
      :toctree: api

      NO_PRECEDENCE
      lprec
      rprec

   .. rubric:: Functions

   .. autosummary::
      :toctree: api

      get_precedences_op
      get_precedence_expr
      get_precedence_lhs
      get_precedence_rhs
